@@ -14,13 +14,14 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.AppBarEvent;
 import org.gnu.gnome.event.AppBarListener;
 import org.gnu.gtk.HBox;
 import org.gnu.gtk.ProgressBar;
 import org.gnu.gtk.StatusBar;
+import org.gnu.javagnome.Handle;
+
 /**
  * The AppBar widget is a progress bar with a textual annotation.
  */
