@@ -13,11 +13,13 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
-import org.gnu.glib.Handle;
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.ClientEvent;
 import org.gnu.gnome.event.ClientListener;
-import org.gnu.gtk.GtkObject;
+import org.gnu.gtk.Dialog;
+import org.gnu.javagnome.Handle;
+
 /**
  * The GnomeClient object makes it possible for your application to
  * save session information when the user logs out. If, when logging
@@ -26,7 +28,7 @@ import org.gnu.gtk.GtkObject;
  * information in such a way that it is supported on the command line
  * whenever the program automatically restarts a user login.
  */
-public class Client extends GtkObject {
+public class Client extends GObject {
 	/**
 	 * Listeners for handling Client events
 	 */
@@ -132,7 +134,52 @@ public class Client extends GtkObject {
 	public void setRestartCommand(String [] args) {
 		gnome_client_set_restart_command(getHandle(), args.length, args);
 	}
-	
+    
+    public void setDiscardCommand(String[] args) {
+        gnome_client_set_discard_command(getHandle(), args.length, args);
+    }
+    
+    public void setResignCommand(String[] args) {
+        gnome_client_set_resign_command(getHandle(), args.length, args);
+    }
+    
+    public void setShutdownCommand(String[] args) {
+        gnome_client_set_shutdown_command(getHandle(), args.length, args);
+    }
+
+    public void setEnvironment(String name, String value) {
+        gnome_client_set_environment(getHandle(), name, value);
+    }
+    
+    public void setCloneCommand(String[] args) {
+        gnome_client_set_clone_command(getHandle(), args.length, args);
+    }
+    
+    public void setProcessID(int id) {
+        gnome_client_set_process_id(getHandle(), id);
+    }
+    
+    public void setProgram(String program) {
+        gnome_client_set_program(getHandle(), program);
+    }
+    
+    public void setUserID(String id) {
+        gnome_client_set_user_id(getHandle(), id);
+    }
+    
+    public void saveAnyDialog(Dialog dialog) {
+        gnome_client_save_any_dialog(getHandle(), dialog.getHandle());
+    }
+    
+    public void saveErrorDialog(Dialog dialog) {
+        gnome_client_save_error_dialog(getHandle(), dialog.getHandle());
+    }
+    
+    public void requestPhase2() {
+        gnome_client_request_phase_2(getHandle());
+    }
+    
+
 	/**
 	 * Request the session manager to save the session in some way.
 	 */
@@ -164,7 +211,24 @@ public class Client extends GtkObject {
 		gnome_client_disconnect(getHandle());
 	}
 
-	/**
+    public void setID(String id) {
+        gnome_client_set_id(getHandle(), id);
+    }
+    
+    public String getID() {
+        return gnome_client_get_id(getHandle());
+    }
+    
+    public String getPreviousID() {
+        return gnome_client_get_previous_id(getHandle());
+    }
+    
+    public String getDesktopID() {
+        return gnome_client_get_desktop_id(getHandle());
+    }
+
+
+    /**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
 	public static Type getType() {
