@@ -13,13 +13,14 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.DruidPageChangeEvent;
 import org.gnu.gnome.event.DruidPageChangeListener;
 import org.gnu.gnome.event.DruidPageSetupEvent;
 import org.gnu.gnome.event.DruidPageSetupListener;
 import org.gnu.gtk.Bin;
+import org.gnu.javagnome.Handle;
+
 /**
  * This widget is a virtual widget to define the interface to a druid
  * page.
@@ -46,6 +47,26 @@ public class DruidPage extends Bin {
 		super(handle);
 	}
 
+    public boolean pageNext() {
+        return gnome_druid_page_next(getHandle());
+    }
+    
+    public void pagePrepare() {
+        gnome_druid_page_prepare(getHandle());
+    }
+    
+    public boolean pageBack() {
+        return gnome_druid_page_back(getHandle());
+    }
+    
+    public boolean pageCancel() {
+        return gnome_druid_page_cancel(getHandle());
+    }
+    
+    public void pageFinish() {
+        gnome_druid_page_finish(getHandle());
+    }
+
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -76,7 +97,7 @@ public class DruidPage extends Bin {
 
 	/**
 	 * Removes a listener
-	 * @see #addListener(DruidPageChangeListeners)
+	 * @see #addListener(DruidPageChangeListener)
 	 */
 	public void removeListener(DruidPageChangeListener listener) {
 		int i = findListener(druidPageChangeListeners, listener);
@@ -124,7 +145,7 @@ public class DruidPage extends Bin {
 	}
 	/**
 	 * Removes a listener
-	 * @see #addListener(DruidPageSetupListeners)
+	 * @see #addListener(DruidPageSetupListener)
 	 */
 	public void removeListener(DruidPageSetupListener listener) {
 		int i = findListener(druidPageSetupListeners, listener);
@@ -150,23 +171,23 @@ public class DruidPage extends Bin {
 		}
 	}
 
-	private boolean handleNext(int widget) {
+	private boolean handleNext(Handle widget) {
 		return fireDruidPageChangeEvent(new DruidPageChangeEvent(this, DruidPageChangeEvent.Type.NEXT));
 	}
 
-	private boolean handleBack(int widget) {
+	private boolean handleBack(Handle widget) {
 		return fireDruidPageChangeEvent(new DruidPageChangeEvent(this, DruidPageChangeEvent.Type.BACK));
 	}
 
-	private void handleFinish(int widget) {
+	private void handleFinish(Handle widget) {
 		fireDruidPageSetupEvent(new DruidPageSetupEvent(this, DruidPageSetupEvent.Type.FINISH));
 	}
 
-	private boolean handleCancel(int widget) {
+	private boolean handleCancel(Handle widget) {
 		return fireDruidPageChangeEvent(new DruidPageChangeEvent(this, DruidPageChangeEvent.Type.CANCEL));
 	}
 
-	private void handlePrepare(int widget) {
+	private void handlePrepare(Handle widget) {
 		fireDruidPageSetupEvent(new DruidPageSetupEvent(this, DruidPageSetupEvent.Type.PREPARE));
 	}
 
