@@ -9,7 +9,7 @@
 
 package org.gnu.gnome;
 
-import org.gnu.glib.Handle;
+import org.gnu.javagnome.Handle;
 
 public class Gnome 
 {
@@ -36,8 +36,8 @@ public class Gnome
 
     static
     {
-		System.loadLibrary ("gtkjni-2.6");
-        System.loadLibrary ("gnomejni-2.10");
+		System.loadLibrary ("gtkjni-2.7");
+        System.loadLibrary ("gnomejni-2.11");
     }
 
     native static final protected Handle gnome_master_client ();
