@@ -10,18 +10,20 @@
 package org.gnu.gnome;
 
 import org.gnu.gdk.ModifierType;
-import org.gnu.glib.Boxed;
-import org.gnu.glib.Handle;
+import org.gnu.glib.GObject;
 import org.gnu.gtk.GtkStockItem;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.event.ButtonEvent;
 import org.gnu.gtk.event.ButtonListener;
 import org.gnu.gtk.event.MenuItemEvent;
 import org.gnu.gtk.event.MenuItemListener;
+import org.gnu.javagnome.Handle;
+import org.gnu.javagnome.Struct;
+
 /**
  *
  */
-public class UIInfo extends Boxed {
+public class UIInfo extends Struct {
 
 	public int getType() {
 		return getType(getHandle());
@@ -53,8 +55,8 @@ public class UIInfo extends Boxed {
 		Handle[] hndls = new Handle[moreInfo.length];
 		for (int i = 0; i < moreInfo.length; i++) 
 			hndls[i] = moreInfo[i].getHandle();
-		if (null != hndls)
-			setSubmenuInfo(getHandle(), hndls);
+                if (null != hndls)
+                    setSubmenuInfo(getHandle(), hndls);
 	    if (null != name && 0 < name.length())
 	    	setPixmapInfo(getHandle(), name);
 	}
@@ -72,7 +74,7 @@ public class UIInfo extends Boxed {
 		for (int i = 0; i < moreInfo.length; i++) 
 			hndls[i] = moreInfo[i].getHandle();
 		if (null != hndls)
-			setSubmenuInfo(getHandle(), hndls);
+                    setSubmenuInfo(getHandle(), hndls);
 		if (null != data)
 			setPixmapInfo(getHandle(), data);
 	}
@@ -171,8 +173,12 @@ public class UIInfo extends Boxed {
 
 	public Widget getWidget(){
 		Handle hndl = getWidget(getHandle());
-		if (null == hndl)
+                if ( hndl == null || hndl.isNull() )
 			return null;
+                GObject obj = GObject.getGObjectFromHandle( hndl );
+                if (obj != null) {
+                    return (Widget)obj;
+                }
 		return new Widget(hndl);
 	}
 
